@@ -58,11 +58,12 @@ class ProfileModel (gtk.ListStore):
     (
         COLUMN_SOURCE,
         COLUMN_PATH,
-        COLUMN_DESCRIPTION
-    ) = range (3)
+        COLUMN_DESCRIPTION,
+        COLUMN_SORTPRIORITY
+    ) = range (4)
 
     def __init__ (self, profile):
-        gtk.ListStore.__init__ (self, str, str, str)
+        gtk.ListStore.__init__ (self, str, str, str, int)
 
         self.profile = profile
         self.reload ()
@@ -75,15 +76,17 @@ class ProfileModel (gtk.ListStore):
             if source is None:
                 source = self.profile.get_delegate (source_name)
             
-            dprint ("  source %s, path %s, description %s",
+            dprint ("  source %s, path %s, description %s, sortpriority %d",
                     source_name,
                     path,
-                    source.get_path_description (path))
+                    source.get_path_description (path),
+                    source.SORTPRIORITY)
             
             self.set (self.prepend (),
                       self.COLUMN_SOURCE,          source_name,
                       self.COLUMN_PATH,            path,
-                      self.COLUMN_DESCRIPTION,     source.get_path_description (path))
+                      self.COLUMN_DESCRIPTION,     source.get_path_description (path),
+                      self.COLUMN_SORTPRIORITY,       source.SORTPRIORITY)
 
 
 class ProfileEditorWindow:
@@ -222,10 +225,32 @@ class ProfileEditorWindow:
         self.save_action = action_group.get_action ("Save")
         self.delete_action = action_group.get_action ("Delete")
 
+    # Sort by Source then alphabetically
+    # Generally this means GConf and other app specific prefs are listed before files
+    def __pref_object_sort_func (self, model, iter1, iter2):
+        sortprio1 = model.get_value (iter1, ProfileModel.COLUMN_SORTPRIORITY)
+        sortprio2 = model.get_value (iter2, ProfileModel.COLUMN_SORTPRIORITY)
+        path1      = model.get_value (iter1, ProfileModel.COLUMN_PATH)
+        path2      = model.get_value (iter2, ProfileModel.COLUMN_PATH)
+        
+        if sortprio1 < sortprio2:
+            return -1
+        if sortprio1 == sortprio2:
+            if path1 < path2:
+                return -1
+            if path1 == path2:
+                return 0
+            if path1 > path2:
+                return 1
+        if sortprio1 > sortprio2:
+            return 1
+
     def __setup_treeview (self):
         self.profile_model = ProfileModel (self.profile)
+        self.profile_sortable = gtk.TreeModelSort (self.profile_model)
+        self.profile_sortable.set_default_sort_func(self.__pref_object_sort_func)
         
-        self.treeview = gtk.TreeView (self.profile_model)
+        self.treeview = gtk.TreeView (self.profile_sortable)
         self.treeview.show ()
         self.scrolled.add (self.treeview)
         
@@ -233,12 +258,16 @@ class ProfileEditorWindow:
         self.treeview.get_selection ().connect ("changed",
                                                 self.__treeview_selection_changed)
 
-        self.treeview.set_headers_visible (False)
+        self.treeview.set_headers_visible (True)
 
         c = gtk.TreeViewColumn (_("Description"),
                                 gtk.CellRendererText (),
                                 text = ProfileModel.COLUMN_DESCRIPTION)
         self.treeview.append_column (c)
+        c = gtk.TreeViewColumn (_("Source"),
+                                gtk.CellRendererText (),
+                                text = ProfileModel.COLUMN_SOURCE)
+        self.treeview.append_column (c)
 
         self.treeview.connect ("key-press-event", self.__handle_key_press)
         self.treeview.connect ("row-activated",   self.__handle_row_activation)
@@ -256,6 +285,7 @@ class ProfileEditorWindow:
 
     @errors.checked_callback (debuglog.DEBUG_LOG_DOMAIN_USER)
     def __handle_row_activation (self, treeview, tree_path, column):
+        tree_path = self.profile_sortable.convert_path_to_child_path (tree_path)
         iter = self.profile_model.get_iter (tree_path)
         path = self.profile_model[iter][ProfileModel.COLUMN_PATH]
         description = self.profile_model[iter][ProfileModel.COLUMN_DESCRIPTION]
