@@ -20,10 +20,12 @@ import gconf
 import util
 import sessionwindow
 
-from sabayon.lockdown import lockdownapplier
+import debuglog
+import errors
+from Pessulus import lockdownappliergconf
 
 def dprint (fmt, *args):
-    util.debug_print (util.DEBUG_ADMINTOOL, fmt % args)
+    debuglog.debug_log (False, debuglog.DEBUG_LOG_DOMAIN_ADMIN_TOOL, fmt % args)
 
 class LockdownMonitor:
     def __init__ (self, key, handler, data):
@@ -32,7 +34,7 @@ class LockdownMonitor:
         self.handler = handler
         self.data = data
 
-class LockdownApplierSabayon (lockdownapplier.PessulusLockdownApplier):
+class LockdownApplierSabayon (lockdownappliergconf.PessulusLockdownApplierGconf):
     def __init__ (self, profile, changes_model):
         self.changes_model = changes_model
         self.source = profile.get_source ("GConf")
@@ -41,6 +43,7 @@ class LockdownApplierSabayon (lockdownapplier.PessulusLockdownApplier):
 
         self.changes_model.connect ("changed", self.__changes_model_changed)
 
+    @errors.checked_callback (debuglog.DEBUG_LOG_DOMAIN_ADMIN_TOOL)
     def __changes_model_changed (self, model, change):
         if change == None or change.get_source () != self.source:
             return
@@ -61,20 +64,45 @@ class LockdownApplierSabayon (lockdownapplier.PessulusLockdownApplier):
             return self.changes_model[iter][sessionwindow.ProfileChangesModel.COLUMN_MANDATORY]
         
         return self.source.get_gconf_key_is_mandatory (key)
-        
-    def get_bool (self, key):
+
+    def get_value (self, key):
         iter = self.changes_model.find (self.source, key)
         if iter:
             change = self.changes_model[iter][sessionwindow.ProfileChangesModel.COLUMN_CHANGE]
-            val = change.value.get_bool()
+            val = change.value
         else:
-            val = self.client.get_bool (key)
+            val = self.client.get (key)
+        return val
         
+    def get_bool (self, key):
+        val = self.get_value (key)
+        if val == None:
+            val = False
+        else:
+            val = val.get_bool()
         return (val, self.__is_mandatory (key))
-            
+
+    def get_int (self, key):
+        val = self.get_value (key)
+        if val != None:
+            val = val.get_int()
+        return (val, self.__is_mandatory (key))
+
+    def get_string (self, key):
+        val = self.get_value (key)
+        if val != None:
+            val = val.get_string()
+        return (val, self.__is_mandatory (key))
+
     def set_bool (self, key, value, mandatory):
         return self.source.set_gconf_boolean (key, value, mandatory)
 
+    def set_int (self, key, value, mandatory):
+        return self.source.set_gconf_int (key, value, mandatory)
+
+    def set_string (self, key, value, mandatory):
+        return self.source.set_gconf_string (key, value, mandatory)
+
     def get_list (self, key, list_type):
         value = self.client.get_list (key, list_type)
         return (value, self.__is_mandatory (key))
